@@ -8,11 +8,11 @@
 #include "igraph.h"
 
 
-#include <iostream>
-using std::cerr;
-using std::endl;
-using std::set;
-using std::map;
+//#include <iostream>
+//using std::cerr;
+//using std::endl;
+//using std::set;
+//using std::map;
 
 /****************************************************************************
 Class for doing community detection using the Leiden algorithm.
@@ -88,9 +88,9 @@ class Optimiser
 template <class T> T* Optimiser::find_partition(Graph* graph)
 {
   T* partition = new T(graph);
-  #ifdef DEBUG
-    cerr << "Use default partition (all nodes in own community)" << endl;
-  #endif
+  //#ifdef DEBUG
+  //  cerr << "Use default partition (all nodes in own community)" << endl;
+  //#endif
   this->optimise_partition(partition);
   return partition;
 }
@@ -98,9 +98,9 @@ template <class T> T* Optimiser::find_partition(Graph* graph)
 template <class T> T* Optimiser::find_partition(Graph* graph, double resolution_parameter)
 {
   T* partition = new T(graph, resolution_parameter);
-  #ifdef DEBUG
-    cerr << "Use default partition (all nodes in own community)" << endl;
-  #endif
+  //#ifdef DEBUG
+  //  cerr << "Use default partition (all nodes in own community)" << endl;
+  //#endif
   this->optimise_partition(partition);
   return partition;
 }
