@@ -6,9 +6,9 @@
 #include "igraph.h"
 
 
-#include <iostream>
-  using std::cerr;
-  using std::endl;
+//#include <iostream>
+//  using std::cerr;
+//  using std::endl;
 
 class SurpriseVertexPartition: public MutableVertexPartition
 {
